@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -38,26 +38,29 @@
 #include "Command.h"
 #include "SharedHandle.h"
 #include "TimeA2.h"
-#include "RequestGroupAware.h"
+#include "FileEntry.h"
+#include "RequestGroup.h"
 
 namespace aria2 {
 
 class Request;
 class DownloadEngine;
-class RequestGroup;
 class Segment;
 class Exception;
 class SocketCore;
+class Option;
 #ifdef ENABLE_ASYNC_DNS
 class AsyncNameResolver;
 #endif // ENABLE_ASYNC_DNS
 
-class AbstractCommand : public Command, public RequestGroupAware {
+class AbstractCommand : public Command {
 private:
   Time checkPoint;
   time_t timeout;
 protected:
+  RequestGroup* _requestGroup;
   SharedHandle<Request> req;
+  SharedHandle<FileEntry> _fileEntry;
   DownloadEngine* e;
   SharedHandle<SocketCore> socket;
   std::deque<SharedHandle<Segment> > _segments;
@@ -99,7 +102,16 @@ protected:
 
   void prepareForNextAction(Command* nextCommand = 0);
 
-  void checkIfConnectionEstablished(const SharedHandle<SocketCore>& socket);
+  // Check if socket is connected. If socket is not connected and
+  // there are other addresses to try, command is created using
+  // InitiateConnectionCommandFactory and it is pushed to
+  // DownloadEngine and returns false. If no addresses left, DlRetryEx
+  // exception is thrown.
+  bool checkIfConnectionEstablished
+  (const SharedHandle<SocketCore>& socket,
+   const std::string& connectedHostname,
+   const std::string& connectedAddr,
+   uint16_t connectedPort);
 
   /*
    * Returns true if proxy for the procol indicated by Request::getProtocol()
@@ -112,6 +124,18 @@ protected:
    * If no valid proxy is defined, then returns SharedHandle<Request>().
    */
   SharedHandle<Request> createProxyRequest() const;
+
+
+  // Returns proxy method for given protocol. Either V_GET or V_TUNNEL
+  // is returned.  For HTTPS, always returns V_TUNNEL.
+  const std::string& resolveProxyMethod(const std::string& protocol) const;
+
+  const SharedHandle<Option>& getOption() const;
+
+  const SharedHandle<DownloadContext>& getDownloadContext() const
+  {
+    return _requestGroup->getDownloadContext();
+  }
 private:
   bool checkSocketIsReadable;
   bool checkSocketIsWritable;
@@ -129,8 +153,9 @@ private:
 #endif // ENABLE_ASYNC_DNS
 public:
   AbstractCommand(int32_t cuid, const SharedHandle<Request>& req,
-		  RequestGroup* requestGroup, DownloadEngine* e,
-		  const SharedHandle<SocketCore>& s = SharedHandle<SocketCore>());
+                  const SharedHandle<FileEntry>& fileEntry,
+                  RequestGroup* requestGroup, DownloadEngine* e,
+                  const SharedHandle<SocketCore>& s = SharedHandle<SocketCore>());
 
   virtual ~AbstractCommand();
   bool execute();
