@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -35,7 +35,7 @@
 #ifndef _D_BT_NOT_INTERESTED_MESSAGE_H_
 #define _D_BT_NOT_INTERESTED_MESSAGE_H_
 
-#include "SimpleBtMessage.h"
+#include "ZeroBtMessage.h"
 
 namespace aria2 {
 
@@ -44,34 +44,21 @@ class BtNotInterestedMessage;
 
 typedef SharedHandle<BtNotInterestedMessage> BtNotInterestedMessageHandle;
 
-class BtNotInterestedMessage : public SimpleBtMessage {
+class BtNotInterestedMessage : public ZeroBtMessage {
 private:
-  unsigned char* msg;
-  
   SharedHandle<PeerStorage> _peerStorage;
-
-  static size_t MESSAGE_LENGTH;
 public:
-  BtNotInterestedMessage():msg(0) {}
-
-  virtual ~BtNotInterestedMessage() {
-    delete [] msg;
-  }
+  BtNotInterestedMessage():ZeroBtMessage(ID, NAME) {}
 
   static const uint8_t ID = 3;
 
-  static BtNotInterestedMessageHandle create(const unsigned char* data, size_t dataLength);
+  static const std::string NAME;
 
-  virtual uint8_t getId() { return ID; }
+  static SharedHandle<BtNotInterestedMessage> create
+  (const unsigned char* data, size_t dataLength);
 
   virtual void doReceivedAction();
 
-  virtual const unsigned char* getMessage();
-
-  virtual size_t getMessageLength();
-
-  virtual std::string toString() const;
-
   virtual bool sendPredicate() const;
 
   virtual void onSendComplete();
