@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -38,48 +38,47 @@
 #include "DiskWriter.h"
 #include <sstream>
 
+namespace aria2 {
+
 class ByteArrayDiskWriter : public DiskWriter {
 private:
-  stringstream buf;
+  std::stringstream buf;
 
   void clear();
 public:
   ByteArrayDiskWriter();
   virtual ~ByteArrayDiskWriter();
 
-  virtual void initAndOpenFile(const string& filename, int64_t totalLength = 0);
+  virtual void initAndOpenFile(uint64_t totalLength = 0);
 
-  virtual void openFile(const string& filename, int64_t totalLength = 0);
+  virtual void openFile(uint64_t totalLength = 0);
 
   virtual void closeFile();
 
-  virtual void openExistingFile(const string& filename, int64_t totalLength = 0);
+  virtual void openExistingFile(uint64_t totalLength = 0);
 
-  virtual void writeData(const unsigned char* data, int32_t len, int64_t position);
-  virtual int32_t readData(unsigned char* data, int32_t len, int64_t position);
+  virtual void writeData(const unsigned char* data, size_t len, off_t position);
+  virtual ssize_t readData(unsigned char* data, size_t len, off_t position);
 
-  // Not implemented yet
-  virtual void truncate(int64_t length) {}
-
-  virtual int64_t size() const
-  {
-    return buf.str().size();
-  }
+  virtual uint64_t size();
 
   virtual void enableDirectIO() {}
 
   virtual void disableDirectIO() {}
 
-  virtual bool directIOAllowed() const
-  {
-    return false;
-  }
-
-  void setString(const string& s)
+  void setString(const std::string& s)
   {
     buf.str(s);
   }
+
+  std::string getString() const
+  {
+    return buf.str();
+  }
 };
 
 typedef SharedHandle<ByteArrayDiskWriter> ByteArrayDiskWriterHandle;
+
+} // namespace aria2
+
 #endif // _D_BYTE_ARRAY_DISK_WRITER_H_
