@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -45,6 +45,8 @@ class Logger;
 
 typedef int32_t CommandUuid;
 
+typedef int32_t cuid_t;
+
 class Command {
 public:
   enum STATUS {
@@ -67,13 +69,13 @@ protected:
   bool _errorEvent;
   bool _hupEvent;
 public:
-  Command(int32_t cuid);
+  Command(cuid_t cuid);
 
   virtual ~Command() {}
 
   virtual bool execute() = 0;
 
-  int32_t getCuid() const { return cuid; }
+  cuid_t getCuid() const { return cuid; }
 
   const CommandUuid& getUuid() const { return uuid; }
 
