@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -38,6 +38,9 @@
 #include "RequestGroup.h"
 #include "PieceStorage.h"
 #include "DiskAdaptor.h"
+#include "DownloadContext.h"
+
+namespace aria2 {
 
 FileAllocationEntry::FileAllocationEntry(RequestGroup* requestGroup, Command* nextCommand):
   RequestGroupEntry(requestGroup, nextCommand),
@@ -51,12 +54,12 @@ FileAllocationEntry:: ~FileAllocationEntry()
   _requestGroup->getPieceStorage()->getDiskAdaptor()->disableDirectIO();
 }
 
-int64_t FileAllocationEntry::getCurrentLength()
+off_t FileAllocationEntry::getCurrentLength()
 {
   return _fileAllocationIterator->getCurrentLength();
 }
 
-int64_t FileAllocationEntry::getTotalLength()
+uint64_t FileAllocationEntry::getTotalLength()
 {
   return _fileAllocationIterator->getTotalLength();
 }
@@ -70,3 +73,10 @@ void FileAllocationEntry::allocateChunk()
 {
   _fileAllocationIterator->allocateChunk();
 }
+
+void FileAllocationEntry::disableDirectIO()
+{
+  _requestGroup->getPieceStorage()->getDiskAdaptor()->disableDirectIO();
+}
+
+} // namespace aria2
