@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -41,7 +41,7 @@
 #include "Request.h"
 #include "Segment.h"
 #include "Option.h"
-#include "Util.h"
+#include "util.h"
 #include "message.h"
 #include "prefs.h"
 #include "LogFactory.h"
@@ -63,9 +63,9 @@ const std::string FtpConnection::A("A");
 const std::string FtpConnection::I("I");
 
 FtpConnection::FtpConnection(int32_t cuid, const SocketHandle& socket,
-			     const RequestHandle& req,
-			     const SharedHandle<AuthConfig>& authConfig,
-			     const Option* op):
+                             const RequestHandle& req,
+                             const SharedHandle<AuthConfig>& authConfig,
+                             const Option* op):
   cuid(cuid), socket(socket), req(req),
   _authConfig(authConfig), option(op),
   logger(LogFactory::getInstance()),
@@ -134,12 +134,12 @@ bool FtpConnection::sendCwd()
 {
   if(_socketBuffer.sendBufferIsEmpty()) {
     logger->info("CUID#%d - Using base working directory '%s'",
-		 cuid, _baseWorkingDir.c_str());
+                 cuid, _baseWorkingDir.c_str());
     std::string request = "CWD ";
     if(_baseWorkingDir != "/") {
       request += _baseWorkingDir;
     }
-    request += Util::urldecode(req->getDir());
+    request += util::urldecode(req->getDir());
     request += "\r\n";
     logger->info(MSG_SENDING_REQUEST, cuid, request.c_str());
     _socketBuffer.feedSendBuffer(request);
@@ -152,7 +152,7 @@ bool FtpConnection::sendMdtm()
 {
   if(_socketBuffer.sendBufferIsEmpty()) {
     std::string request = "MDTM ";
-    request += Util::urlencode(req->getFile());
+    request += util::urlencode(req->getFile());
     request += "\r\n";
     logger->info(MSG_SENDING_REQUEST, cuid, request.c_str());
     _socketBuffer.feedSendBuffer(request);
@@ -165,7 +165,7 @@ bool FtpConnection::sendSize()
 {
   if(_socketBuffer.sendBufferIsEmpty()) {
     std::string request = "SIZE ";
-    request += Util::urldecode(req->getFile());
+    request += util::urldecode(req->getFile());
     request += "\r\n";
     logger->info(MSG_SENDING_REQUEST, cuid, request.c_str());
     _socketBuffer.feedSendBuffer(request);
@@ -201,20 +201,20 @@ bool FtpConnection::sendPort(const SharedHandle<SocketCore>& serverSocket)
     socket->getAddrInfo(addrinfo);
     unsigned int ipaddr[4]; 
     sscanf(addrinfo.first.c_str(), "%u.%u.%u.%u",
-	   &ipaddr[0], &ipaddr[1], &ipaddr[2], &ipaddr[3]);
+           &ipaddr[0], &ipaddr[1], &ipaddr[2], &ipaddr[3]);
     serverSocket->getAddrInfo(addrinfo);
     std::string request = "PORT ";
-    request += Util::uitos(ipaddr[0]);
+    request += util::uitos(ipaddr[0]);
     request += ",";
-    request += Util::uitos(ipaddr[1]);
+    request += util::uitos(ipaddr[1]);
     request += ",";
-    request += Util::uitos(ipaddr[2]);
+    request += util::uitos(ipaddr[2]);
     request += ",";
-    request += Util::uitos(ipaddr[3]);
+    request += util::uitos(ipaddr[3]);
     request += ",";
-    request += Util::uitos(addrinfo.second/256);
+    request += util::uitos(addrinfo.second/256);
     request += ",";
-    request += Util::uitos(addrinfo.second%256);
+    request += util::uitos(addrinfo.second%256);
     request += "\r\n";
     logger->info(MSG_SENDING_REQUEST, cuid, request.c_str());
     _socketBuffer.feedSendBuffer(request);
@@ -230,7 +230,7 @@ bool FtpConnection::sendRest(const SegmentHandle& segment)
     if(segment.isNull()) {
       request += "0";
     } else {
-      request += Util::itos(segment->getPositionToWrite());
+      request += util::itos(segment->getPositionToWrite());
     }
     request += "\r\n";
     
@@ -245,7 +245,7 @@ bool FtpConnection::sendRetr()
 {
   if(_socketBuffer.sendBufferIsEmpty()) {
     std::string request = "RETR ";
-    request += Util::urldecode(req->getFile());
+    request += util::urldecode(req->getFile());
     request += "\r\n";
     logger->info(MSG_SENDING_REQUEST, cuid, request.c_str());
     _socketBuffer.feedSendBuffer(request);
@@ -272,10 +272,10 @@ unsigned int FtpConnection::getStatus(const std::string& response) const
 
 // Returns the length of the reponse if the whole response has been received.
 // The length includes \r\n.
-// If the whole response has not been recieved, then returns std::string::npos.
+// If the whole response has not been received, then returns std::string::npos.
 std::string::size_type
 FtpConnection::findEndOfResponse(unsigned int status,
-				 const std::string& buf) const
+                                 const std::string& buf) const
 {
   if(buf.size() <= 4) {
     return std::string::npos;
@@ -286,7 +286,7 @@ FtpConnection::findEndOfResponse(unsigned int status,
     std::string::size_type p;
 
     std::string endPattern = A2STR::CRLF;
-    endPattern += Util::uitos(status);
+    endPattern += util::uitos(status);
     endPattern += " ";
     p = buf.find(endPattern);
     if(p == std::string::npos) {
@@ -317,14 +317,14 @@ bool FtpConnection::bulkReceiveResponse(std::pair<unsigned int, std::string>& re
     socket->readData(buf, size);
     if(size == 0) {
       if(socket->wantRead() || socket->wantWrite()) {
-	return false;
+        return false;
       }
       throw DL_RETRY_EX(EX_GOT_EOF);
     }
     if(strbuf.size()+size > MAX_RECV_BUFFER) {
       throw DL_RETRY_EX
-	(StringFormat("Max FTP recv buffer reached. length=%lu",
-		      static_cast<unsigned long>(strbuf.size()+size)).str());
+        (StringFormat("Max FTP recv buffer reached. length=%lu",
+                      static_cast<unsigned long>(strbuf.size()+size)).str());
     }
     strbuf.append(&buf[0], &buf[size]);
   }
@@ -378,8 +378,8 @@ unsigned int FtpConnection::receiveSizeResponse(uint64_t& size)
   std::pair<unsigned int, std::string> response;
   if(bulkReceiveResponse(response)) {
     if(response.first == 213) {
-      std::pair<std::string, std::string> rp = Util::split(response.second," ");
-      size = Util::parseULLInt(rp.second);
+      std::pair<std::string, std::string> rp = util::split(response.second," ");
+      size = util::parseULLInt(rp.second);
     }
     return response.first;
   } else {
@@ -396,24 +396,24 @@ unsigned int FtpConnection::receiveMdtmResponse(Time& time)
       char buf[15]; // YYYYMMDDhhmmss+\0, milli second part is dropped.
       sscanf(response.second.c_str(), "%*u %14s", buf);
       if(strlen(buf) == 14) {
-	// We don't use Time::parse(buf,"%Y%m%d%H%M%S") here because Mac OS X
-	// and included strptime doesn't parse data for this format.
-	struct tm tm;
-	memset(&tm, 0, sizeof(tm));
-	tm.tm_sec = Util::parseInt(&buf[12]);
-	buf[12] = '\0';
-	tm.tm_min = Util::parseInt(&buf[10]);
-	buf[10] = '\0';
-	tm.tm_hour = Util::parseInt(&buf[8]);
-	buf[8] = '\0';
-	tm.tm_mday = Util::parseInt(&buf[6]);
-	buf[6] = '\0';
-	tm.tm_mon = Util::parseInt(&buf[4])-1;
-	buf[4] = '\0';
-	tm.tm_year = Util::parseInt(&buf[0])-1900;
-	time = Time(timegm(&tm));
+        // We don't use Time::parse(buf,"%Y%m%d%H%M%S") here because Mac OS X
+        // and included strptime doesn't parse data for this format.
+        struct tm tm;
+        memset(&tm, 0, sizeof(tm));
+        tm.tm_sec = util::parseInt(&buf[12]);
+        buf[12] = '\0';
+        tm.tm_min = util::parseInt(&buf[10]);
+        buf[10] = '\0';
+        tm.tm_hour = util::parseInt(&buf[8]);
+        buf[8] = '\0';
+        tm.tm_mday = util::parseInt(&buf[6]);
+        buf[6] = '\0';
+        tm.tm_mon = util::parseInt(&buf[4])-1;
+        buf[4] = '\0';
+        tm.tm_year = util::parseInt(&buf[0])-1900;
+        time = Time(timegm(&tm));
       } else {
-	time = Time::null();
+        time = Time::null();
       }
     }
     return response.first;
@@ -431,21 +431,21 @@ unsigned int FtpConnection::receivePasvResponse(std::pair<std::string, uint16_t>
       unsigned int h1, h2, h3, h4, p1, p2;
       std::string::size_type p = response.second.find("(");
       if(p >= 4) {
-	sscanf(response.second.substr(response.second.find("(")).c_str(),
-	       "(%u,%u,%u,%u,%u,%u).",
-	       &h1, &h2, &h3, &h4, &p1, &p2);
-	// ip address
- 	dest.first = Util::uitos(h1);
- 	dest.first += ".";
-	dest.first += Util::uitos(h2);
-	dest.first += ".";
-	dest.first += Util::uitos(h3);
-	dest.first += ".";
-	dest.first += Util::uitos(h4);
-	// port number
-	dest.second = 256*p1+p2;
+        sscanf(response.second.substr(response.second.find("(")).c_str(),
+               "(%u,%u,%u,%u,%u,%u).",
+               &h1, &h2, &h3, &h4, &p1, &p2);
+        // ip address
+        dest.first = util::uitos(h1);
+        dest.first += ".";
+        dest.first += util::uitos(h2);
+        dest.first += ".";
+        dest.first += util::uitos(h3);
+        dest.first += ".";
+        dest.first += util::uitos(h4);
+        // port number
+        dest.second = 256*p1+p2;
       } else {
-	throw DL_RETRY_EX(EX_INVALID_RESPONSE);
+        throw DL_RETRY_EX(EX_INVALID_RESPONSE);
       }
     }
     return response.first;
@@ -463,10 +463,10 @@ unsigned int FtpConnection::receivePwdResponse(std::string& pwd)
       std::string::size_type last;
 
       if((first = response.second.find("\"")) != std::string::npos &&
-	 (last = response.second.find("\"", ++first)) != std::string::npos) {
-	pwd = response.second.substr(first, last-first);
+         (last = response.second.find("\"", ++first)) != std::string::npos) {
+        pwd = response.second.substr(first, last-first);
       } else {
-	throw DL_ABORT_EX(EX_INVALID_RESPONSE);
+        throw DL_ABORT_EX(EX_INVALID_RESPONSE);
       }
     }
     return response.first;
