@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -35,22 +35,24 @@
 #ifndef _D_FTP_INITIATE_CONNECTION_COMMAND_H_
 #define _D_FTP_INITIATE_CONNECTION_COMMAND_H_
 
-#include "AbstractCommand.h"
+#include "InitiateConnectionCommand.h"
 
-class FtpInitiateConnectionCommand : public AbstractCommand {
-private:
-  NameResolverHandle nameResolver;
-  bool useHttpProxy() const;
-  bool useHttpProxyGet() const;
-  bool useHttpProxyConnect() const;
-#ifdef ENABLE_ASYNC_DNS
-  virtual bool nameResolveFinished() const;
-#endif // ENABLE_ASYNC_DNS
+namespace aria2 {
+
+class FtpInitiateConnectionCommand : public InitiateConnectionCommand {
 protected:
-  virtual bool executeInternal();
+  virtual Command* createNextCommand
+  (const std::string& hostname, const std::string& addr, uint16_t port,
+   const std::deque<std::string>& resolvedAddresses,
+   const SharedHandle<Request>& proxyRequest);
 public:
-  FtpInitiateConnectionCommand(int cuid, const RequestHandle& req, RequestGroup* requestGroup, DownloadEngine* e);
+  FtpInitiateConnectionCommand(int cuid, const SharedHandle<Request>& req,
+                               const SharedHandle<FileEntry>& fileEntry,
+                               RequestGroup* requestGroup, DownloadEngine* e);
+
   virtual ~FtpInitiateConnectionCommand();
 };
 
+} // namespace aria2
+
 #endif // _D_FTP_INITIATE_CONNECTION_COMMAND_H_
