@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -37,16 +37,24 @@
 
 #include "AbstractProxyRequestCommand.h"
 
+namespace aria2 {
+
+class SocketCore;
+
 class FtpTunnelRequestCommand : public AbstractProxyRequestCommand {
 public:
   FtpTunnelRequestCommand(int cuid,
-			  const RequestHandle& req,
-			  RequestGroup* requestGroup,
-			  DownloadEngine* e,
-			  const SocketHandle& s);
+                          const SharedHandle<Request>& req,
+                          const SharedHandle<FileEntry>& fileEntry,
+                          RequestGroup* requestGroup,
+                          DownloadEngine* e,
+                          const SharedHandle<Request>& proxyRequest,
+                          const SharedHandle<SocketCore>& s);
   virtual ~FtpTunnelRequestCommand();
 
   virtual Command* getNextCommand();
 };
 
+} // namespace aria2
+
 #endif // _D_FTP_TUNNEL_REQUEST_COMMAND_H_
