@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -37,10 +37,12 @@
 
 #include "TimeBasedCommand.h"
 
+namespace aria2 {
+
 class HaveEraseCommand : public TimeBasedCommand
 {
 public:
-  HaveEraseCommand(int32_t cuid, DownloadEngine* e, int32_t interval);
+  HaveEraseCommand(int32_t cuid, DownloadEngine* e, time_t interval);
 
   virtual ~HaveEraseCommand();
 
@@ -49,4 +51,6 @@ public:
   virtual void process();
 };
 
+} // namespace aria2
+
 #endif // _D_HAVE_ERASE_COMMAND_H_
