@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -36,28 +36,46 @@
 #define _D_PEER_INITIATE_CONNECTION_H_
 
 #include "PeerAbstractCommand.h"
-#include "RequestGroupAware.h"
-#include "BtContextAwareCommand.h"
 
-class PeerInitiateConnectionCommand : public PeerAbstractCommand,
-				      public BtContextAwareCommand,
-				      public RequestGroupAware
-{
+namespace aria2 {
+
+class RequestGroup;
+class BtRuntime;
+class PeerStorage;
+class PieceStorage;
+
+class PeerInitiateConnectionCommand : public PeerAbstractCommand {
+private:
+  RequestGroup* _requestGroup;
+
+  SharedHandle<BtRuntime> _btRuntime;
+
+  SharedHandle<PeerStorage> _peerStorage;
+
+  SharedHandle<PieceStorage> _pieceStorage;
+
+  bool _mseHandshakeEnabled;
 protected:
   virtual bool executeInternal();
-  virtual bool prepareForRetry(int wait);
-  virtual bool prepareForNextPeer(int wait);
-  virtual void onAbort(Exception* ex);
+  virtual bool prepareForNextPeer(time_t wait);
+  virtual void onAbort();
   virtual bool exitBeforeExecute();
 
 public:
   PeerInitiateConnectionCommand(int cuid,
-				RequestGroup* requestGroup,
-				const PeerHandle& peer,
-				DownloadEngine* e,
-				const BtContextHandle& btContext);
+                                RequestGroup* requestGroup,
+                                const SharedHandle<Peer>& peer,
+                                DownloadEngine* e,
+                                const SharedHandle<BtRuntime>& btRuntime,
+                                bool mseHandshakeEnabled = true);
 
   virtual ~PeerInitiateConnectionCommand();
+
+  void setPeerStorage(const SharedHandle<PeerStorage>& peerStorage);
+
+  void setPieceStorage(const SharedHandle<PieceStorage>& pieceStorage);
 };
 
+} // namespace aria2
+
 #endif // _D_PEER_INITIATE_CONNECTION_H_
