@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -36,18 +36,21 @@
 #define _D_PEER_LISTEN_COMMAND_H_
 
 #include "Command.h"
-#include "Socket.h"
+#include "SharedHandle.h"
 #include "IntSequence.h"
 
+namespace aria2 {
+
 class DownloadEngine;
+class SocketCore;
 
 class PeerListenCommand : public Command {
 private:
   DownloadEngine* e;
-  SocketHandle socket;
-  int32_t _lowestSpeedLimit;
+  SharedHandle<SocketCore> socket;
+  unsigned int _lowestSpeedLimit;
 
-  static int32_t __numInstance;
+  static unsigned int __numInstance;
 
   static PeerListenCommand* __instance;
 
@@ -58,20 +61,29 @@ public:
   
   virtual bool execute();
 
-  int32_t bindPort(IntSequence& seq);
+  /**
+   * Binds port. If successful, the binded port number is assinged to port and
+   * returns true, otherwise port is undefined and returns false.
+   */
+  bool bindPort(uint16_t& port, IntSequence& seq);
 
-  void setLowestSpeedLimit(int32_t speed)
+  // Returns binded port
+  uint16_t getPort() const;
+
+  void setLowestSpeedLimit(unsigned int speed)
   {
     _lowestSpeedLimit = speed;
   }
 
   static PeerListenCommand* getInstance(DownloadEngine* e);
 
-  static int32_t getNumInstance()
+  static unsigned int getNumInstance()
   {
     return __numInstance;
   }
   
 };
 
+} // namespace aria2 
+
 #endif // _D_PEER_LISTEN_COMMAND_H_
