@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -41,7 +41,7 @@ namespace aria2 {
 
 class SimpleBtMessage : public AbstractBtMessage {
 public:
-  SimpleBtMessage();
+  SimpleBtMessage(uint8_t id, const std::string& name);
 
   virtual ~SimpleBtMessage();
 
