@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -115,6 +115,10 @@ const std::string KEY_VERSION = "version";
 const std::string KEY_ENABLED_FEATURES = "enabledFeatures";
 const std::string KEY_METHOD_NAME = "methodName";
 const std::string KEY_PARAMS = "params";
+const std::string KEY_SESSION_ID = "sessionId";
+const std::string KEY_FILES = "files";
+const std::string KEY_DIR = "dir";
+const std::string KEY_URIS = "uris";
 }
 
 static BDE createGIDResponse(int32_t gid)
@@ -123,8 +127,8 @@ static BDE createGIDResponse(int32_t gid)
 }
 
 static BDE addRequestGroup(const SharedHandle<RequestGroup>& group,
-			   DownloadEngine* e,
-			   bool posGiven, int pos)
+                           DownloadEngine* e,
+                           bool posGiven, int pos)
 {
   if(posGiven) {
     e->_requestGroupMan->insertReservedGroup(pos, group);
@@ -140,7 +144,7 @@ static bool hasDictParam(const BDE& params, size_t index)
 }
 
 static void getPosParam(const BDE& params, size_t posParamIndex,
-			bool& posGiven, size_t& pos)
+                        bool& posGiven, size_t& pos)
 {
   if(params.size() > posParamIndex && params[posParamIndex].isInteger()) {
     if(params[posParamIndex].i() >= 0) {
@@ -179,8 +183,8 @@ BDE AddUriXmlRpcMethod::process(const XmlRpcRequest& req, DownloadEngine* e)
 
   std::deque<SharedHandle<RequestGroup> > result;
   createRequestGroupForUri(result, requestOption, uris,
-			   /* ignoreForceSeq = */ true,
-			   /* ignoreLocalPath = */ true);
+                           /* ignoreForceSeq = */ true,
+                           /* ignoreLocalPath = */ true);
 
   if(!result.empty()) {
     return addRequestGroup(result.front(), e, posGiven, pos);
@@ -202,9 +206,9 @@ BDE AddTorrentXmlRpcMethod::process
   std::deque<std::string> uris;
   if(params.size() > 1 && params[1].isList()) {
     for(BDE::List::const_iterator i = params[1].listBegin();
-	i != params[1].listEnd(); ++i) {
+        i != params[1].listEnd(); ++i) {
       if((*i).isString()) {
-	uris.push_back((*i).s());
+        uris.push_back((*i).s());
       }
     }
   }
@@ -218,8 +222,8 @@ BDE AddTorrentXmlRpcMethod::process
 
   std::deque<SharedHandle<RequestGroup> > result;
   createRequestGroupForBitTorrent(result, requestOption,
-				  uris,
-				  params[0].s());
+                                  uris,
+                                  params[0].s());
 
   if(!result.empty()) {
     return addRequestGroup(result.front(), e, posGiven, pos);
@@ -257,7 +261,7 @@ BDE AddMetalinkXmlRpcMethod::process
     }
     BDE gids = BDE::list();
     for(std::deque<SharedHandle<RequestGroup> >::const_iterator i =
-	  result.begin(); i != result.end(); ++i) {
+          result.begin(); i != result.end(); ++i) {
       gids << BDE(util::itos((*i)->getGID()));
     }
     return gids;
@@ -284,13 +288,13 @@ BDE RemoveXmlRpcMethod::process(const XmlRpcRequest& req, DownloadEngine* e)
     group = e->_requestGroupMan->findReservedGroup(gid);
     if(group.isNull()) {
       throw DL_ABORT_EX
-	(StringFormat("Active Download not found for GID#%d", gid).str());
+        (StringFormat("Active Download not found for GID#%d", gid).str());
     }
     if(group->isDependencyResolved()) {
       e->_requestGroupMan->removeReservedGroup(gid);
     } else {
       throw DL_ABORT_EX
-	(StringFormat("GID#%d cannot be removed now", gid).str());
+        (StringFormat("GID#%d cannot be removed now", gid).str());
     }
   } else {
     group->setHaltRequested(true, RequestGroup::USER_REQUEST);
@@ -299,6 +303,31 @@ BDE RemoveXmlRpcMethod::process(const XmlRpcRequest& req, DownloadEngine* e)
   return createGIDResponse(gid);
 }
 
+template<typename InputIterator>
+static void createFileEntry(BDE& files, InputIterator first, InputIterator last)
+{
+  size_t index = 1;
+  for(; first != last; ++first, ++index) {
+    BDE entry = BDE::dict();
+    entry[KEY_INDEX] = util::uitos(index);
+    entry[KEY_PATH] = (*first)->getPath();
+    entry[KEY_SELECTED] = (*first)->isRequested()?BDE_TRUE:BDE_FALSE;
+    entry[KEY_LENGTH] = util::uitos((*first)->getLength());
+
+    BDE uriList = BDE::list();
+    std::deque<std::string> uris;
+    (*first)->getUris(uris);
+    for(std::deque<std::string>::const_iterator i = uris.begin();
+        i != uris.end(); ++i) {
+      BDE uriEntry = BDE::dict();
+      uriEntry[KEY_URI] = *i;
+      uriList << uriEntry;
+    }
+    entry[KEY_URIS] = uriList;
+    files << entry;
+  }
+}
+
 void gatherProgressCommon
 (BDE& entryDict, const SharedHandle<RequestGroup>& group)
 {
@@ -316,18 +345,17 @@ void gatherProgressCommon
   if(!ps.isNull()) {
     if(ps->getBitfieldLength() > 0) {
       entryDict[KEY_BITFIELD] = util::toHex(ps->getBitfield(),
-					    ps->getBitfieldLength());
+                                            ps->getBitfieldLength());
     }
   }
-  entryDict[KEY_PIECE_LENGTH] = 
-    util::uitos(group->getDownloadContext()->getPieceLength());
-  entryDict[KEY_NUM_PIECES] =
-    util::uitos(group->getDownloadContext()->getNumPieces());
+  const SharedHandle<DownloadContext>& dctx = group->getDownloadContext();
+  entryDict[KEY_PIECE_LENGTH] = util::uitos(dctx->getPieceLength());
+  entryDict[KEY_NUM_PIECES] = util::uitos(dctx->getNumPieces());
   if(!group->followedBy().empty()) {
     BDE list = BDE::list();
     // The element is GID.
     for(std::vector<int32_t>::const_iterator i = group->followedBy().begin();
-	i != group->followedBy().end(); ++i) {
+        i != group->followedBy().end(); ++i) {
       list << util::itos(*i);
     }
     entryDict[KEY_FOLLOWED_BY] = list;
@@ -335,6 +363,11 @@ void gatherProgressCommon
   if(group->belongsTo()) {
     entryDict[KEY_BELONGS_TO] = util::itos(group->belongsTo());
   }
+  BDE files = BDE::list();
+  createFileEntry
+    (files, dctx->getFileEntries().begin(), dctx->getFileEntries().end());
+  entryDict[KEY_FILES] = files;
+  entryDict[KEY_DIR] = group->getOption()->get(PREF_DIR);
 }
 
 #ifdef ENABLE_BITTORRENT
@@ -359,14 +392,14 @@ static void gatherPeer(BDE& peers, const SharedHandle<PeerStorage>& ps)
   std::deque<SharedHandle<Peer> > activePeers;
   ps->getActivePeers(activePeers);
   for(std::deque<SharedHandle<Peer> >::const_iterator i =
-	activePeers.begin(); i != activePeers.end(); ++i) {
+        activePeers.begin(); i != activePeers.end(); ++i) {
     BDE peerEntry = BDE::dict();
     peerEntry[KEY_PEER_ID] = util::torrentUrlencode((*i)->getPeerId(),
-						PEER_ID_LENGTH);
+                                                    PEER_ID_LENGTH);
     peerEntry[KEY_IP] = (*i)->ipaddr;
     peerEntry[KEY_PORT] = util::uitos((*i)->port);
     peerEntry[KEY_BITFIELD] = util::toHex((*i)->getBitfield(),
-					(*i)->getBitfieldLength());
+                                          (*i)->getBitfieldLength());
     peerEntry[KEY_AM_CHOKING] = (*i)->amChoking()?BDE_TRUE:BDE_FALSE;
     peerEntry[KEY_PEER_CHOKING] = (*i)->peerChoking()?BDE_TRUE:BDE_FALSE;
     TransferStat stat = ps->getTransferStatFor(*i);
@@ -408,7 +441,7 @@ void gatherStoppedDownload
     BDE list = BDE::list();
     // The element is GID.
     for(std::vector<int32_t>::const_iterator i = ds->followedBy.begin();
-	i != ds->followedBy.end(); ++i) {
+        i != ds->followedBy.end(); ++i) {
       list << util::itos(*i);
     }
     entryDict[KEY_FOLLOWED_BY] = list;
@@ -416,6 +449,9 @@ void gatherStoppedDownload
   if(ds->belongsTo) {
     entryDict[KEY_BELONGS_TO] = util::itos(ds->belongsTo);
   }
+  BDE files = BDE::list();
+  createFileEntry(files, ds->fileEntries.begin(), ds->fileEntries.end());
+  entryDict[KEY_FILES] = files;
 }
 
 static
@@ -429,20 +465,6 @@ findRequestGroup(const SharedHandle<RequestGroupMan>& rgman, int32_t gid)
   return group;
 }
 
-template<typename InputIterator>
-static void createFileEntry(BDE& files, InputIterator first, InputIterator last)
-{
-  size_t index = 1;
-  for(; first != last; ++first, ++index) {
-    BDE entry = BDE::dict();
-    entry[KEY_INDEX] = util::uitos(index);
-    entry[KEY_PATH] = (*first)->getPath();
-    entry[KEY_SELECTED] = (*first)->isRequested()?BDE_TRUE:BDE_FALSE;
-    entry[KEY_LENGTH] = util::uitos((*first)->getLength());
-    files << entry;
-  }
-}
-
 BDE GetFilesXmlRpcMethod::process
 (const XmlRpcRequest& req, DownloadEngine* e)
 {
@@ -462,14 +484,14 @@ BDE GetFilesXmlRpcMethod::process
       e->_requestGroupMan->findDownloadResult(gid);
     if(dr.isNull()) {
       throw DL_ABORT_EX
-	(StringFormat("No file data is available for GID#%d", gid).str());
+        (StringFormat("No file data is available for GID#%d", gid).str());
     } else {
       createFileEntry(files, dr->fileEntries.begin(), dr->fileEntries.end());
     }
   } else {
     createFileEntry(files,
-		    group->getDownloadContext()->getFileEntries().begin(),
-		    group->getDownloadContext()->getFileEntries().end());
+                    group->getDownloadContext()->getFileEntries().begin(),
+                    group->getDownloadContext()->getFileEntries().end());
   }
   return files;
 }
@@ -492,12 +514,12 @@ BDE GetUrisXmlRpcMethod::process
       (StringFormat("No URI data is available for GID#%d", gid).str());
   }
   BDE uriList = BDE::list();
-  std::deque<std::string> uris;
   // TODO Current implementation just returns first FileEntry's URIs.
   if(!group->getDownloadContext()->getFileEntries().empty()) {
+    std::deque<std::string> uris;
     group->getDownloadContext()->getFirstFileEntry()->getUris(uris);
     for(std::deque<std::string>::const_iterator i = uris.begin();
-	i != uris.end(); ++i) {
+        i != uris.end(); ++i) {
       BDE entry = BDE::dict();
       entry[KEY_URI] = *i;
       uriList << entry;
@@ -553,10 +575,10 @@ BDE TellStatusXmlRpcMethod::process
     group = e->_requestGroupMan->findReservedGroup(gid);
     if(group.isNull()) {
       SharedHandle<DownloadResult> ds =
-	e->_requestGroupMan->findDownloadResult(gid);
+        e->_requestGroupMan->findDownloadResult(gid);
       if(ds.isNull()) {
-	throw DL_ABORT_EX
-	  (StringFormat("No such download for GID#%d", gid).str());
+        throw DL_ABORT_EX
+          (StringFormat("No such download for GID#%d", gid).str());
       }
       gatherStoppedDownload(entryDict, ds);
     } else {
@@ -577,7 +599,7 @@ BDE TellActiveXmlRpcMethod::process
   const std::deque<SharedHandle<RequestGroup> >& groups =
     e->_requestGroupMan->getRequestGroups();
   for(std::deque<SharedHandle<RequestGroup> >::const_iterator i =
-	groups.begin(); i != groups.end(); ++i) {
+        groups.begin(); i != groups.end(); ++i) {
     BDE entryDict = BDE::dict();
     entryDict[KEY_STATUS] = BDE_ACTIVE;
     gatherProgress(entryDict, *i, e);
@@ -586,73 +608,43 @@ BDE TellActiveXmlRpcMethod::process
   return list;
 }
 
-template<typename InputIterator>
-static std::pair<InputIterator, InputIterator>
-getPaginationRange
-(const XmlRpcRequest& req, InputIterator first, InputIterator last)
+template<typename T>
+void AbstractPaginationXmlRpcMethod<T>::checkPaginationParams
+(const BDE& params) const
 {
-  const BDE& params = req._params;
   assert(params.isList());
-
   if(params.size() != 2 ||
      !params[0].isInteger() || !params[1].isInteger() ||
-     params[0].i() < 0 || params[1].i() < 0) {
+     params[1].i() < 0) {
     throw DL_ABORT_EX("Invalid argument. Specify offset and num in integer.");
   }
-
-  size_t offset = params[0].i();
-  size_t num = params[1].i();
-
-  BDE list = BDE::list();
-  size_t size = std::distance(first, last);
-  if(size <= offset) {
-    return std::make_pair(last, last);
-  }
-  size_t lastDistance;
-  if(size < offset+num) {
-    lastDistance = size;
-  } else {
-    lastDistance = offset+num;
-  }
-  last = first;
-  std::advance(first, offset);
-  std::advance(last, lastDistance);
-  return std::make_pair(first, last);
 }
 
-BDE TellWaitingXmlRpcMethod::process
-(const XmlRpcRequest& req, DownloadEngine* e)
+const std::deque<SharedHandle<RequestGroup> >&
+TellWaitingXmlRpcMethod::getItems(DownloadEngine* e) const
 {
-  const std::deque<SharedHandle<RequestGroup> >& waitings =
-    e->_requestGroupMan->getReservedGroups();
-  std::pair<std::deque<SharedHandle<RequestGroup> >::const_iterator,
-    std::deque<SharedHandle<RequestGroup> >::const_iterator> range =
-    getPaginationRange(req, waitings.begin(), waitings.end());
-  BDE list = BDE::list();
-  for(; range.first != range.second; ++range.first) {
-    BDE entryDict = BDE::dict();
-    entryDict[KEY_STATUS] = BDE_WAITING;
-    gatherProgress(entryDict, *range.first, e);
-    list << entryDict;
-  }
-  return list;
+  return e->_requestGroupMan->getReservedGroups();
 }
 
-BDE TellStoppedXmlRpcMethod::process
-(const XmlRpcRequest& req, DownloadEngine* e)
+void TellWaitingXmlRpcMethod::createEntry
+(BDE& entryDict, const SharedHandle<RequestGroup>& item,
+ DownloadEngine* e) const
 {
-  const std::deque<SharedHandle<DownloadResult> >& stopped =
-    e->_requestGroupMan->getDownloadResults();
-  std::pair<std::deque<SharedHandle<DownloadResult> >::const_iterator,
-    std::deque<SharedHandle<DownloadResult> >::const_iterator> range =
-    getPaginationRange(req, stopped.begin(), stopped.end());
-  BDE list = BDE::list();
-  for(; range.first != range.second; ++range.first) {
-    BDE entryDict = BDE::dict();
-    gatherStoppedDownload(entryDict, *range.first);
-    list << entryDict;
-  }
-  return list;
+  entryDict[KEY_STATUS] = BDE_WAITING;
+  gatherProgress(entryDict, item, e);
+}
+
+const std::deque<SharedHandle<DownloadResult> >&
+TellStoppedXmlRpcMethod::getItems(DownloadEngine* e) const
+{
+  return e->_requestGroupMan->getDownloadResults();
+}
+
+void TellStoppedXmlRpcMethod::createEntry
+(BDE& entryDict, const SharedHandle<DownloadResult>& item,
+ DownloadEngine* e) const
+{
+  gatherStoppedDownload(entryDict, item);
 }
 
 BDE PurgeDownloadResultXmlRpcMethod::process
@@ -683,7 +675,7 @@ BDE ChangeOptionXmlRpcMethod::process
     applyChangeableOption(group->getOption().get(), option.get());
     if(option->defined(PREF_MAX_DOWNLOAD_LIMIT)) {
       group->setMaxDownloadSpeedLimit
-	(option->getAsInt(PREF_MAX_DOWNLOAD_LIMIT));
+        (option->getAsInt(PREF_MAX_DOWNLOAD_LIMIT));
     }
     if(option->defined(PREF_MAX_UPLOAD_LIMIT)) {
       group->setMaxUploadSpeedLimit(option->getAsInt(PREF_MAX_UPLOAD_LIMIT));
@@ -692,7 +684,7 @@ BDE ChangeOptionXmlRpcMethod::process
     BtObject btObject = e->getBtRegistry()->get(group->getGID());
     if(!btObject.isNull()) {
       if(option->defined(PREF_BT_MAX_PEERS)) {
-	btObject._btRuntime->setMaxPeers(option->getAsInt(PREF_BT_MAX_PEERS));
+        btObject._btRuntime->setMaxPeers(option->getAsInt(PREF_BT_MAX_PEERS));
       }
     }
 #endif // ENABLE_BITTORRENT
@@ -819,6 +811,14 @@ BDE ChangePositionXmlRpcMethod::process
   return result;
 }
 
+BDE GetSessionInfoXmlRpcMethod::process
+(const XmlRpcRequest& req, DownloadEngine* e)
+{
+  BDE result = BDE::dict();
+  result[KEY_SESSION_ID] = util::toHex(e->getSessionId());
+  return result;
+}
+
 BDE SystemMulticallXmlRpcMethod::process
 (const XmlRpcRequest& req, DownloadEngine* e)
 {
@@ -834,19 +834,19 @@ BDE SystemMulticallXmlRpcMethod::process
       i != methodSpecs.listEnd(); ++i) {
     if(!(*i).isDict()) {
       list << createErrorResponse
-	(DL_ABORT_EX("system.multicall expected struct."));
+        (DL_ABORT_EX("system.multicall expected struct."));
       continue;
     }
     if(!(*i).containsKey(KEY_METHOD_NAME) ||
        !(*i).containsKey(KEY_PARAMS)) {
       list << createErrorResponse
-	(DL_ABORT_EX("Missing methodName or params."));
+        (DL_ABORT_EX("Missing methodName or params."));
       continue;
     }
     const std::string& methodName = (*i)[KEY_METHOD_NAME].s();
     if(methodName == getMethodName()) {
       list << createErrorResponse
-	(DL_ABORT_EX("Recursive system.multicall forbidden."));
+        (DL_ABORT_EX("Recursive system.multicall forbidden."));
       continue;
     }
     SharedHandle<XmlRpcMethod> method = XmlRpcMethodFactory::create(methodName);
