@@ -1,9 +1,13 @@
 #include "BtHaveMessage.h"
-#include "PeerMessageUtil.h"
+
+#include <cstring>
+
+#include <cppunit/extensions/HelperMacros.h>
+
+#include "bittorrent_helper.h"
 #include "Peer.h"
 #include "MockPieceStorage.h"
-#include <cstring>
-#include <cppunit/extensions/HelperMacros.h>
+#include "DlAbortEx.h"
 
 namespace aria2 {
 
@@ -13,6 +17,7 @@ class BtHaveMessageTest:public CppUnit::TestFixture {
   CPPUNIT_TEST(testCreate);
   CPPUNIT_TEST(testGetMessage);
   CPPUNIT_TEST(testDoReceivedAction);
+  CPPUNIT_TEST(testDoReceivedAction_goodByeSeeder);
   CPPUNIT_TEST(testToString);
   CPPUNIT_TEST_SUITE_END();
 private:
@@ -24,6 +29,7 @@ public:
   void testCreate();
   void testGetMessage();
   void testDoReceivedAction();
+  void testDoReceivedAction_goodByeSeeder();
   void testToString();
 };
 
@@ -32,8 +38,8 @@ CPPUNIT_TEST_SUITE_REGISTRATION(BtHaveMessageTest);
 
 void BtHaveMessageTest::testCreate() {
   unsigned char msg[9];
-  PeerMessageUtil::createPeerMessageString(msg, sizeof(msg), 5, 4);
-  PeerMessageUtil::setIntParam(&msg[5], 12345);
+  bittorrent::createPeerMessageString(msg, sizeof(msg), 5, 4);
+  bittorrent::setIntParam(&msg[5], 12345);
   SharedHandle<BtHaveMessage> pm = BtHaveMessage::create(&msg[4], 5);
   CPPUNIT_ASSERT_EQUAL((uint8_t)4, pm->getId());
   CPPUNIT_ASSERT_EQUAL((size_t)12345, pm->getIndex());
@@ -41,7 +47,7 @@ void BtHaveMessageTest::testCreate() {
   // case: payload size is wrong
   try {
     unsigned char msg[10];
-    PeerMessageUtil::createPeerMessageString(msg, sizeof(msg), 6, 4);
+    bittorrent::createPeerMessageString(msg, sizeof(msg), 6, 4);
     BtHaveMessage::create(&msg[4], 2);
     CPPUNIT_FAIL("exception must be thrown.");
   } catch(...) {
@@ -49,7 +55,7 @@ void BtHaveMessageTest::testCreate() {
   // case: id is wrong
   try {
     unsigned char msg[9];
-    PeerMessageUtil::createPeerMessageString(msg, sizeof(msg), 5, 5);
+    bittorrent::createPeerMessageString(msg, sizeof(msg), 5, 5);
     BtHaveMessage::create(&msg[4], 1);
     CPPUNIT_FAIL("exception must be thrown.");
   } catch(...) {
@@ -60,8 +66,8 @@ void BtHaveMessageTest::testGetMessage() {
   BtHaveMessage msg;
   msg.setIndex(12345);
   unsigned char data[9];
-  PeerMessageUtil::createPeerMessageString(data, sizeof(data), 5, 4);
-  PeerMessageUtil::setIntParam(&data[5], 12345);
+  bittorrent::createPeerMessageString(data, sizeof(data), 5, 4);
+  bittorrent::setIntParam(&data[5], 12345);
   CPPUNIT_ASSERT(memcmp(msg.getMessage(), data, 9) == 0);
 }
 
@@ -80,6 +86,39 @@ void BtHaveMessageTest::testDoReceivedAction() {
 
   CPPUNIT_ASSERT(peer->hasPiece(msg.getIndex()));
 }
+
+void BtHaveMessageTest::testDoReceivedAction_goodByeSeeder()
+{
+  SharedHandle<Peer> peer(new Peer("ip", 6000));
+  peer->allocateSessionResource(1024, 2*1024);
+  BtHaveMessage msg;
+  msg.setIndex(0);
+  msg.setPeer(peer);
+  SharedHandle<MockPieceStorage> pieceStorage(new MockPieceStorage());
+  msg.setPieceStorage(pieceStorage);
+
+  // peer is not seeder and client have not completed download
+  msg.doReceivedAction();
+
+  pieceStorage->setDownloadFinished(true);
+
+  // client have completed download but, peer is not seeder
+  msg.doReceivedAction();
+
+  msg.setIndex(1);
+  pieceStorage->setDownloadFinished(false);
+
+  // peer is a seeder but client have not completed download
+  msg.doReceivedAction();
+
+  pieceStorage->setDownloadFinished(true);
+  try {
+    msg.doReceivedAction();
+    CPPUNIT_FAIL("exception must be thrown.");
+  } catch(DlAbortEx& e) {
+    // success
+  }
+}
   
 void BtHaveMessageTest::testToString() {
   BtHaveMessage msg;
